// Copyright (C) 2008 - INRIA
// Copyright (C) 2009-2011 - DIGITEO
// Copyright (C) 2013 - Scilab Enterprises
// Copyright (C) 2018 - Samuel GOUGEON

// This file is released under the 3-clause BSD license. See COPYING-BSD.

function main_builder()

    TOOLBOX_NAME  = "SIMM";
    TOOLBOX_TITLE = "SIMM toolbox";
    toolbox_dir   = get_absolute_file_path("builder.sce");

    // Localization
    // ========================================================================
    addlocalizationdomain("simm", toolbox_dir+"/locales")

    // Check Scilab's version
    // ========================================================================

    // check minimal version (xcosPal required)
    if ~isdef('xcosPal') then
        // and xcos features required
        error(_("simm", 'Scilab 5.3.2 or more is required.'));
    end

    // Check modules_manager module availability
    // ========================================================================

    if ~isdef('tbx_build_loader') then
        error(msprintf(_("simm", "%s module not installed."), 'modules_manager'));
    end

    // Check modules_manager module availability
    // ========================================================================
    try
        getCoselicaVersion();
    catch
        if atomsIsInstalled("coselica")
            atomsLoad("coselica");
        else
            error(msprintf(_("simm", "%s module not installed."), 'coselica'))
        end
    end

    // Action
    // ========================================================================

    tbx_builder_macros(toolbox_dir);
    //tbx_builder_help(toolbox_dir);
    v = getversion("scilab");
    if v(1)>5 then
        tbx_build_localization(toolbox_dir);
        tbx_build_loader(toolbox_dir);
        tbx_build_cleaner(toolbox_dir);
    else
        tbx_build_localization(TOOLBOX_NAME, toolbox_dir);
        tbx_build_loader(TOOLBOX_NAME, toolbox_dir);
        tbx_build_cleaner(TOOLBOX_NAME, toolbox_dir);
    end
endfunction

if with_module('xcos') then
    main_builder();
    clear main_builder; // remove main_builder on stack
end
